<?php

namespace Shop;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Psr\Container\ContainerInterface;
use Slim\Factory\AppFactory;
use DI\Container;
use Shop\DB\myDB;
use Shop\View\Twig;
use Shop\DB\Order;
use Shop\Model\Order as OrderModel;

require __DIR__ . '/../vendor/autoload.php';

$container = new Container();
AppFactory::setContainer($container);
$app = AppFactory::create();

$container->set('twig', function () {
    $twig = new Twig('../templates');
    return $twig;
});

$container->set(
    'db',
    function () {
        $db = new myDB();
        return $db;
    }
);


$app->get("/orders/{client}/create", \Shop\Controller\ClientCreate::class . ':createGet');
$app->post("/orders/{client}/create", \Shop\Controller\ClientCreate::class . ':createPost');

// Route with optional params, see https://www.slimframework.com/docs/v4/objects/routing.html#how-to-create-routes section Optional segments

$app->get('/orders', \Shop\Controller\Orders::class . ':orders');
$app->get('/orders/{client}', \Shop\Controller\Orders::class . ':ordersArgs');

$app->get("/order/{id}/create", \Shop\Controller\OrderCreate::class . ':createGet');
$app->post("/order/{id}/create", \Shop\Controller\OrderCreate::class . ':createPost');

$app->get('/order/{id}', \Shop\Controller\OrderID::class . ':orderID');

$app->get('/customers', \Shop\Controller\Clients::class . ':clients');

$app->run();
